from setuptools import setup

setup(name='distributions_test_450',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['distributions_test_450'],
      author=['anonymous'],
      zip_safe=False)
